==> com.liferay.layout.content.page.editor.web-1.0.20.jar: META-INF/resources/js/components/sidebar/FragmentsEditorSidebar.es.js <==
"use strict";

Liferay.Loader.define("layout-content-page-editor-web@1.0.20/js/components/sidebar/FragmentsEditorSidebar.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-state', 'frontend-js-metal-web$metal-soy', './FragmentsEditorSidebarContent.es', '../../store/ConnectedComponent.es', '../../actions/actions.es', './FragmentsEditorSidebar.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.default = exports.FragmentsEditorSidebar = exports.ConnectedFragmentsEditorSidebar = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  require("./FragmentsEditorSidebarContent.es");

  var _ConnectedComponent = require("../../store/ConnectedComponent.es");

  var _actions = require("../../actions/actions.es");

  var _FragmentsEditorSidebar = _interopRequireDefault(require("./FragmentsEditorSidebar.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { default: obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * FragmentsEditorSidebar
   * @review
   */
  var FragmentsEditorSidebar =
  /*#__PURE__*/
  function (_Component) {
    _inherits(FragmentsEditorSidebar, _Component);

    function FragmentsEditorSidebar() {
      _classCallCheck(this, FragmentsEditorSidebar);

      return _possibleConstructorReturn(this, _getPrototypeOf(FragmentsEditorSidebar).apply(this, arguments));
    }

    _createClass(FragmentsEditorSidebar, [{
      key: "created",

      /**
       * @inheritDoc
       * @review
       */
      value: function created() {
        this._productMenuToggle = $('.product-menu-toggle');
        this._productMenu = $(this._productMenuToggle.data('target'));
        this._handleHide = this._handleHide.bind(this);

        this._productMenu.on('openStart.lexicon.sidenav', this._handleHide);
      }
      /**
       * @inheritDoc
       * @review
       */

    }, {
      key: "disposed",
      value: function disposed() {
        this._productMenu.off('openStart.lexicon.sidenav', this._handleHide);
      }
      /**
       * @inheritDoc
       * @review
       */

    }, {
      key: "rendered",
      value: function rendered() {
        if (this.selectedSidebarPanelId) {
          this._productMenuToggle.sideNavigation('hide');
        }
      }
      /**
       * @private
       * @review
       */

    }, {
      key: "_handleHide",
      value: function _handleHide() {
        this.store.dispatch({
          sidebarPanelId: '',
          type: _actions.UPDATE_SELECTED_SIDEBAR_PANEL_ID
        });
      }
    }]);

    return FragmentsEditorSidebar;
  }(_metalComponent.default);
  /**
   * State definition.
   * @review
   * @static
   * @type {!Object}
   */

  exports.FragmentsEditorSidebar = FragmentsEditorSidebar;
  FragmentsEditorSidebar.STATE = {
    /**
     * Synced ProductMenu sidebar.
     * @default undefined
     * @instance
     * @memberOf FragmentsEditorSidebar
     * @review
     * @type {object}
     */
    _productMenu: _metalState.Config.internal(),

    /**
     * Synced ProductMenu toggle button.
     * @default undefined
     * @instance
     * @memberOf FragmentsEditorSidebar
     * @review
     * @type {object}
     */
    _productMenuToggle: _metalState.Config.internal()
  };
  var ConnectedFragmentsEditorSidebar = (0, _ConnectedComponent.getConnectedComponent)(FragmentsEditorSidebar, ['selectedSidebarPanelId']);
  exports.ConnectedFragmentsEditorSidebar = ConnectedFragmentsEditorSidebar;

  _metalSoy.default.register(ConnectedFragmentsEditorSidebar, _FragmentsEditorSidebar.default);

  var _default = ConnectedFragmentsEditorSidebar;
  exports.default = _default;
  //# sourceMappingURL=FragmentsEditorSidebar.es.js.map
});
//# sourceMappingURL=FragmentsEditorSidebar.es.js.map

==> com.liferay.layout.content.page.editor.web-1.0.52.jar: META-INF/resources/js/components/sidebar/FragmentsEditorSidebar.es.js <==
Liferay.Loader.define("layout-content-page-editor-web@1.0.52/js/components/sidebar/FragmentsEditorSidebar.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', 'frontend-js-metal-web$metal-state', './FragmentsEditorSidebarContent.es', '../../actions/actions.es', '../../store/ConnectedComponent.es', './FragmentsEditorSidebar.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.FragmentsEditorSidebar = exports.ConnectedFragmentsEditorSidebar = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  require("./FragmentsEditorSidebarContent.es");

  var _actions = require("../../actions/actions.es");

  var _ConnectedComponent = require("../../store/ConnectedComponent.es");

  var _FragmentsEditorSidebar = _interopRequireDefault(require("./FragmentsEditorSidebar.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * FragmentsEditorSidebar
   * @review
   */
  var FragmentsEditorSidebar =
  /*#__PURE__*/
  function (_Component) {
    _inherits(FragmentsEditorSidebar, _Component);

    function FragmentsEditorSidebar() {
      _classCallCheck(this, FragmentsEditorSidebar);

      return _possibleConstructorReturn(this, _getPrototypeOf(FragmentsEditorSidebar).apply(this, arguments));
    }

    _createClass(FragmentsEditorSidebar, [{
      key: "created",

      /**
       * @inheritDoc
       * @review
       */
      value: function created() {
        var productMenuToggle = document.querySelector('.product-menu-toggle');

        if (productMenuToggle) {
          this._productMenuToggle = productMenuToggle;
          this._handleHide = this._handleHide.bind(this);
          var sidenav = Liferay.SideNavigation.instance(this._productMenuToggle);
          this._toggleHandle = sidenav.on('openStart.lexicon.sidenav', this._handleHide);
        }
      }
      /**
       * @inheritDoc
       * @review
       */

    }, {
      key: "disposed",
      value: function disposed() {
        this._toggleHandle.removeListener('openStart.lexicon.sidenav', this._handleHide);
      }
      /**
       * @inheritDoc
       * @review
       */

    }, {
      key: "rendered",
      value: function rendered() {
        var _this = this;

        var selectedSidebarPanel = this.sidebarPanels.find(function (panel) {
          return panel.sidebarPanelId === _this.selectedSidebarPanelId;
        });

        if (selectedSidebarPanel) {
          Liferay.SideNavigation.hide(this._productMenuToggle);
        }
      }
      /**
       * @private
       * @review
       */

    }, {
      key: "_handleHide",
      value: function _handleHide() {
        this.store.dispatch({
          type: _actions.UPDATE_SELECTED_SIDEBAR_PANEL_ID,
          value: ''
        });
      }
    }]);

    return FragmentsEditorSidebar;
  }(_metalComponent["default"]);
  /**
   * State definition.
   * @review
   * @static
   * @type {!Object}
   */

  exports.FragmentsEditorSidebar = FragmentsEditorSidebar;
  FragmentsEditorSidebar.STATE = {
    /**
     * Synced ProductMenu toggle button.
     * @default undefined
     * @instance
     * @memberOf FragmentsEditorSidebar
     * @review
     * @type {object}
     */
    _productMenuToggle: _metalState.Config.internal(),

    /**
     * Internal property for subscribing to sidenav events.
     * @default undefined
     * @instance
     * @memberOf FragmentsEditorSidebar
     * @review
     * @type {EventHandle}
     */
    _toggleHandle: _metalState.Config.internal()
  };
  var ConnectedFragmentsEditorSidebar = (0, _ConnectedComponent.getConnectedComponent)(FragmentsEditorSidebar, ['selectedSidebarPanelId', 'sidebarPanels']);
  exports.ConnectedFragmentsEditorSidebar = ConnectedFragmentsEditorSidebar;

  _metalSoy["default"].register(ConnectedFragmentsEditorSidebar, _FragmentsEditorSidebar["default"]);

  var _default = ConnectedFragmentsEditorSidebar;
  exports["default"] = _default;
  //# sourceMappingURL=FragmentsEditorSidebar.es.js.map
});
//# sourceMappingURL=FragmentsEditorSidebar.es.js.map
